# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.22.3](https://github.com/mamba-org/rattler/compare/rattler_lock-v0.22.2...rattler_lock-v0.22.3) - 2024-04-25

### Fixed
- compare `UrlOrPath` ([#618](https://github.com/mamba-org/rattler/pull/618))
- parse absolute paths on Windows correctly in lockfiles ([#616](https://github.com/mamba-org/rattler/pull/616))

## [0.22.2](https://github.com/mamba-org/rattler/compare/rattler_lock-v0.22.1...rattler_lock-v0.22.2) - 2024-04-19

### Other
- update dependencies incl. reqwest ([#606](https://github.com/mamba-org/rattler/pull/606))

## [0.22.1](https://github.com/baszalmstra/rattler/compare/rattler_lock-v0.22.0...rattler_lock-v0.22.1) - 2024-04-05

### Other
- updated the following local packages: rattler_conda_types

## [0.22.0](https://github.com/mamba-org/rattler/compare/rattler_lock-v0.21.0...rattler_lock-v0.22.0) - 2024-03-30

### Added
- editable pypi packages ([#581](https://github.com/mamba-org/rattler/pull/581))

## [0.21.0](https://github.com/mamba-org/rattler/compare/rattler_lock-v0.20.2...rattler_lock-v0.21.0) - 2024-03-21

### Added
- allow passing pypi paths ([#572](https://github.com/mamba-org/rattler/pull/572))

## [0.20.2](https://github.com/mamba-org/rattler/compare/rattler_lock-v0.20.1...rattler_lock-v0.20.2) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/mamba-org/rattler/pull/563))

## [0.20.1](https://github.com/mamba-org/rattler/compare/rattler_lock-v0.20.0...rattler_lock-v0.20.1) - 2024-03-08

### Fixed
- chrono deprecation warnings ([#558](https://github.com/mamba-org/rattler/pull/558))

## [0.20.0](https://github.com/mamba-org/rattler/compare/rattler_lock-v0.19.0...rattler_lock-v0.20.0) - 2024-03-06

### Added
- sort extras by name and urls by filename ([#540](https://github.com/mamba-org/rattler/pull/540))

### Fixed
- dont use workspace dependencies for local crates ([#546](https://github.com/mamba-org/rattler/pull/546))

### Other
- every crate should have its own version ([#557](https://github.com/mamba-org/rattler/pull/557))
- bump pep508_rs and pep440_rs ([#549](https://github.com/mamba-org/rattler/pull/549))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_lock-v0.18.0...rattler_lock-v0.19.0) - 2024-02-26
